@@ -1,12 +1,4 @@
 # vim: set ts=2 sts=2 sw=2 expandtab smarttab:
-#
-# This file is part of Git-DescribeVersion
-#
-# This software is copyright (c) 2010 by Randy Stauner.
-#
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-#
 package GitDVTest;
 use strict;
 use Exporter;
@@ -16,7 +8,9 @@ our @EXPORT = qw(
   &expect_warning
   &expectation
   &test_expectations
+  &mock_gr
   &mock_gw
+  &return_args
   @versions
   @commits
   @counts
@@ -72,6 +66,8 @@ sub expectation ($$$) {
   } keys %values };
 }
 
+sub return_args { shift if ref $_[0]; return @_ }
+
 sub test_expectations ($$$&) {
   my ($gv, $version, $commits, $sub) = @_;
   my $exps = expectation($gv, $version, $commits);
@@ -81,9 +77,23 @@ sub test_expectations ($$$&) {
   }
 }
 
-sub mock_gw () {
+my $mocked = {};
+
+sub mock_gr {
+  return $mocked->{gr} ||=
+    mock_wrapper(qw(Git::Repository run command));
+}
+sub mock_gw {
+  return $mocked->{gw} ||=
+    mock_wrapper(qw(Git::Wrapper describe count_objects __version));
+}
+
+sub mock_wrapper () {
+  my ($pack, @methods) = @_;
   my $mock = Test::MockObject->new();
-  $mock->fake_module('Git::Wrapper');
+  my %methods = map { ($_, \&return_args) } @methods;
+  $mock->fake_module($pack, %methods);
+  $mock->mock($_ => $methods{$_}) for keys %methods;
   $mock;
 }
 
